@@ -125,15 +125,18 @@ class ModelThemes(ModelTemplate):
     def __init__(self, path, binary_path=None):
         super().__init__()
         self.model, self.binary = self.load_model(path, binary_path)
+        self.pre_process = True
 
     def load_model(self, path, binary_path):
 
-        model_file = open(path, "rb").read()
-        model = pickle.loads(model_file)
+        model_file = open(path, "rb")
+        model = pickle.loads(model_file.read())
+        model_file.close()
 
         if binary_path:
-            binary_model_file = open(binary_path, "rb").read()
-            binary_model = pickle.loads(binary_model_file)
+            binary_model_file = open(binary_path, "rb")
+            binary_model = pickle.loads(binary_model_file.read())
+            binary_model_file.close()
         else:
             binary_model = None
 
@@ -144,14 +147,18 @@ class ModelThemes(ModelTemplate):
         Treats the data to be inserted into the model
         """
 
-        parsed_data = [preprocess(data[0])]
+        if(self.pre_process):
+            parsed_data = [preprocess(data[0])]
+        else:
+            parsed_data = data
 
         emb = HashingVectorizer(n_features=2**14).fit_transform(parsed_data)
 
         return emb
 
-    def inference(self, process):
+    def inference(self, process, pre_process=True):
 
+        self.pre_process = pre_process
         process_aux = process.copy()
 
         for i, document in enumerate(process_aux):
